@@ -1,4 +1,4 @@
 from .sharpify import View;
 from .sharpify import httpGet, httpPost;
-from .sharpify import map_routes;
+from .sharpify import use_mvc;
 
